#[non_exhaustive]pub enum StrictError {
ValueCountMismatch {
expected: usize,
got: usize,
},
TypeMismatch {
column: String,
expected: ColumnType,
},
NullViolation(String),
TruncatedTuple {
expected: usize,
got: usize,
},
ColumnOutOfRange {
index: usize,
count: usize,
},
CorruptOffset {
offset: u32,
len: usize,
},
NewerSchemaVersion {
tuple_version: u16,
reader_version: u16,
},
InvalidMagic {
expected: u32,
got: u32,
},
InvalidFormatVersion {
expected: u8,
got: u8,
},
}Expand description
Errors from Binary Tuple encoding and decoding.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ValueCountMismatch
Wrong number of values for the schema.
TypeMismatch
A value’s type doesn’t match the schema column type.
NullViolation(String)
A non-nullable column received a null value with no default.
TruncatedTuple
Tuple bytes are too short to contain the header.
ColumnOutOfRange
Column index out of range for the schema.
CorruptOffset
Offset table entry points outside the tuple.
NewerSchemaVersion
Schema version in tuple is newer than the reader’s schema.
InvalidMagic
Magic bytes at the start of the tuple do not match MAGIC.
InvalidFormatVersion
Format version byte does not match FORMAT_VERSION.