StrictError

Enum StrictError 

pub enum StrictError {
    ValueCountMismatch {
        expected: usize,
        got: usize,
    },
    TypeMismatch {
        column: String,
        expected: ColumnType,
    },
    NullViolation(String),
    TruncatedTuple {
        expected: usize,
        got: usize,
    },
    ColumnOutOfRange {
        index: usize,
        count: usize,
    },
    CorruptOffset {
        offset: u32,
        len: usize,
    },
    NewerSchemaVersion {
        tuple_version: u16,
        reader_version: u16,
    },
}
Errors from Binary Tuple encoding and decoding.

Variants



ValueCountMismatch

Wrong number of values for the schema.

Fields

expected: usize
got: usize


TypeMismatch

A value’s type doesn’t match the schema column type.

Fields

column: String
expected: ColumnType


NullViolation(String)

A non-nullable column received a null value with no default.



TruncatedTuple

Tuple bytes are too short to contain the header.

Fields

expected: usize
got: usize


ColumnOutOfRange

Column index out of range for the schema.

Fields

index: usize
count: usize


CorruptOffset

Offset table entry points outside the tuple.

Fields

offset: u32
len: usize


NewerSchemaVersion

Schema version in tuple is newer than the reader’s schema.

Fields

tuple_version: u16
reader_version: u16